Garleek: An extra flavor to ONIOM
=================================

.. image:: docs/_static/images/garleek.png

Garleek (recursive acronym for  *Garleek is Automated Resources for Layered Energies using External Keyword*) allows you to perform QM/MM calculations by interfacing Gaussian with MM programs via its ``external`` keyword.

    |    *Wel loved he garleek, oynons, and eek lekes,*
    |    *And for to drynken strong wyn, reed as blood.*
    |    -- **Geoffrey Chaucer**


Documentation & Support
=======================

Documentation is available in the ``docs/`` folder and always compiled as HTML at `readthedocs.io <https://garleek.readthedocs.io>`_. Any doubts can be submitted as an issue `here <https://github.com/insilichem/garleek/issues>`_.

Citation & Funding
==================

Garleek is scientific software, funded by public research grants: Spanish MINECO (project ``CTQ2017-87889-P``, ``CTQ‐2017–87792‐R``, Severo Ochoa Excellence Accreditation 2014–2018 ``SEV‐2013‐0319``), Generalitat de Catalunya (project ``2014SGR989``, CERCA Programme); J.R.-G.P.: Generalitat de Catalunya (grant ``2017FI_B2_00168``); I.F.-A.: Spanish MINECO (Severo Ochoa predoctoral training fellowship ``SVP‐2014–068662``). If you make use of Garleek in scientific publications, please link back to this repository (a publication is under preparation). It will help measure the impact of our research and future funding!